summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAdrian Holovaty <adrian@holovaty.com>2006-07-11 03:09:14 +0000
committerAdrian Holovaty <adrian@holovaty.com>2006-07-11 03:09:14 +0000
commit1805bbb6cd477e0556123f645849d02d5c407a35 (patch)
treeb506627d3c739400348a8f6ed0558a7d5f1768e7
parent93b21610b9decbda74b848a249f739534400f919 (diff)
downloaddjango-1805bbb6cd477e0556123f645849d02d5c407a35.tar.gz
Changed runtests.py to set USE_I18N=True for testing
git-svn-id: http://code.djangoproject.com/svn/django/trunk@3319 bcc190cf-cafb-0310-a4f2-bffc1f526a37
-rwxr-xr-xtests/runtests.py3
1 files changed, 2 insertions, 1 deletions
diff --git a/tests/runtests.py b/tests/runtests.py
index e5e9c18fca..b98a739249 100755
--- a/tests/runtests.py
+++ b/tests/runtests.py
@@ -99,8 +99,9 @@ class TestRunner:
# Manually set INSTALLED_APPS to point to the test models.
settings.INSTALLED_APPS = ALWAYS_INSTALLED_APPS + ['.'.join(a) for a in get_test_models()]
# Manually set DEBUG = False.
settings.DEBUG = False
+ settings.USE_I18N = True
from django.db import connection
from django.core import management
@@ -99,8 +99,9 @@ class TestRunner:
# Manually set INSTALLED_APPS to point to the test models.
settings.INSTALLED_APPS = ALWAYS_INSTALLED_APPS + ['.'.join(a) for a in get_test_models()]
- # Manually set DEBUG = False.
+ # Manually set DEBUG and USE_I18N.
settings.DEBUG = False